;;; pipe.scm: pipe the output of program to remote buddy.
;;; author: Anand Babu <ab@gnu.org.in>

;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License as
;;; published by the Free Software Foundation; either version 2, or (at
;;; your option) any later version.
;;; 
;;; This program is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;;; General Public License for more details.
;;; 
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA

;;; this pipe.scm extension will be automatically loaded through
;;; init.scm
;;; usage:
;;; FREEHOO!> /pipe buddy command [arguments]
;;;

(use-modules (ice-9 popen))

(define (send-message-pipe buddy cmd)
  "send the output of PROGRAM to remote buddy"
  (let*
      ((port (open-input-pipe cmd))
       (line (read-line port)))
    (while (not (eof-object? line))
	   (fh-send-message buddy line)
	   (display line)(newline)
	   (usleep 100000) ; for proper message sequencing
	   (set! line (read-line port)))
    (close-pipe port)))

(define (/pipe args)
  "dynamic command interface to pipe facility"
  (let
      ((args (list->strlist args)))
    (if (>= (length args) 2)
	(send-message-pipe (car args) (list->asv (cdr args) " "))
	(display "usage: /pipe BUDDY COMMAND [OPTIONS]\n"))))

(fh-register-command! '("/pipe" "/pipe BUDDY COMMAND [OPTIONS]\n\t- send the output of COMMAND to BUDDY"))

(define (pipe args)
  "dynamic command interface to pipe buddy"
  (let
      ((args (list->strlist args)))
    (if (>= (length args) 2)
	(begin
	  (send-message-pipe (car args) (list->asv (cdr args) " "))
	  (fh-set-current-target-buddy! (string-append "pipe " (car args)) "send")))))

(fh-register-command! '("pipe" "pipe BUDDY COMMAND [OPTIONS]\n\t- send the output of COMMAND to BUDDY"))
